abacusai.feature — AbacusAI documentation

# abacusai.feature

## Classes

`Feature` | A feature in a feature group

## Module Contents

class abacusai.feature.Feature(client, name=None, selectClause=None, featureMapping=None, sourceTable=None, originalName=None, usingClause=None, orderClause=None, whereClause=None, featureType=None, dataType=None, detectedFeatureType=None, detectedDataType=None, columns={}, pointInTimeInfo={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A feature in a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column

    - selectClause (str) – The sql logic for creating this feature’s data

    - featureMapping (str) – The Feature Mapping of the feature

    - sourceTable (str) – The source table of the column

    - originalName (str) – The original name of the column

    - usingClause (str) – Nested Column Using Clause

    - orderClause (str) – Nested Column Ordering Clause

    - whereClause (str) – Nested Column Where Clause

    - featureType (str) – Feature Type of the Feature

    - dataType (str) – Data Type of the Feature

    - detectedFeatureType (str) – The detected feature type of the column

    - detectedDataType (str) – The detected data type of the column

    - columns (NestedFeature) – Nested Features

    - pointInTimeInfo (PointInTimeFeature) – Point in time column information

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict